#!/bin/bash

WGET=/usr/bin/wget
OPENSSL=/usr/bin/openssl
RM=/bin/rm
LOGGER=/usr/bin/logger
MAIL=/usr/bin/mail
CAT=/bin/cat
GREP=/bin/grep
APACHECTL=/usr/sbin/apache2ctl
CP=/bin/cp
C_REHASH=/usr/bin/c_rehash

CERTS=/etc/apache2/ssl/
REASON=/tmp/reason.$$

CRLPATH_MISP=/etc/apache2/ssl
CRLPATH_SK=http://www.sk.ee/crls/esteid
CRLPATH_SK_JUUR=http://www.sk.ee/crls/juur
NEWCRLPATH_SK=http://www.sk.ee/repository/crls
ADMIN=root

fail()
{
	if [ x != "x$1" ]; then
		TEXT=$1
	else
		TEXT="Internal error"
	fi
	${LOGGER} -p user.err $1
	if [ x != "x$2" ]; then
		${CAT} ${REASON} 
	else
		echo "Reason unknown" 
	fi

	exit 1;
}

update_crl()
{
	rc=0

	crl=$1
	oldcrl="${CRLPATH_MISP}/${crl}.der"
	newcrl=${crl}
	url=${CRLPATH_SK}/${crl}
	if [ ${crl} == "crl.crl" ]; then
		url=${CRLPATH_SK_JUUR}/${crl}
	fi
        if [[ "$newcrl" == 'esteid2011.crl' ]]; then
                url=${NEWCRLPATH_SK}/${crl}
        fi

	pemcrl="${CRLPATH_MISP}/${crl}.pem"

	cd /tmp
	${RM} -f ${REASON} ${newcrl}
	if [ $? != 0 ]; then
		fail "Unable to remove old temporary file"
	fi 
	${CP} -fp ${oldcrl} ${newcrl} > ${REASON} 2>&1

	oldstamp=`ls -l ${newcrl} 2>&1`
	${WGET} -N --cache=off ${url} > ${REASON} 2>&1
	if [ $? != 0 ]; then
		fail "Unable to retrieve new CRL" 1
	fi
	newstamp=`ls -l ${newcrl} 2>&1`

	if [ "$oldstamp" != "$newstamp" ]; then
		${CP} -fp ${newcrl} ${oldcrl} > ${REASON} 2>&1
		${OPENSSL} crl -CApath ${CERTS} -noout -inform DER < ${newcrl} > ${REASON} 2>&1
		${GREP} "verify OK" ${REASON}
		if [ $? != 0 ]; then
			fail "Unable to verify CRL" 1
		fi

		${RM} -f ${pemcrl}
		${OPENSSL} crl -inform DER -outform PEM < ${newcrl} > ${pemcrl}

		rc=1
	fi
	
	if [ -f ${REASON} ]; then
		${RM} -f ${REASON}
	fi
	
	return $rc
}

dorestart=0
for crl in esteid2007.crl esteid2011.crl esteid2015.crl; do
	update_crl $crl

	if [ $PIPESTATUS == 1 ]; then
		dorestart=1
	fi
done

if [ $dorestart == 1 -a ! "$1" = "norestart" ]; then
	${C_REHASH} ${CERTS}
	${APACHECTL} restart
fi
